@@ -12,7 +12,7 @@
 skprGUIbrowser = function() {
   appDir = system.file("shiny", "skprGUI", package = "skpr")
   if (appDir == "") {
-    stop("Could not find example directory. Try re-installing `skpr`.", call. = FALSE)
+    stop("skpr: Could not find example directory. Try re-installing `skpr`.", call. = FALSE)
   }
 
   shiny::runApp(appDir, display.mode = "normal")
