@@ -493,18 +493,6 @@ function(input, output, session) {
       first = paste(c(first, ", <br>", rep("&nbsp;", 20),
                       "splitplotdesign = design_htc"), collapse = "")
     }
-    if (input$trials %% input$numberblocks == 0) {
-      sizevector = input$trials / input$numberblocks
-    } else {
-      sizevector = c(rep(ceiling(input$trials / input$numberblocks), input$numberblocks))
-      unbalancedruns = ceiling(input$trials / input$numberblocks) * input$numberblocks - input$trials
-      sizevector[(length(sizevector) - unbalancedruns + 1):length(sizevector)] = sizevector[(length(sizevector) - unbalancedruns + 1):length(sizevector)] - 1
-      sizevector = paste0(c("c(", paste0(sizevector, collapse = ","), ")"), collapse = "")
-    }
-    if (isblockingtext()) {
-      first = paste(c(first, ", <br>", rep("&nbsp;", 20),
-                      "blocksizes = ", sizevector), collapse = "")
-    }
     if (input$optimality != "D") {
       first = paste(c(first, ", <br>", rep("&nbsp;", 20),
                       "optimality = \"", input$optimality, "\""), collapse = "")
@@ -810,20 +798,12 @@ function(input, output, session) {
                            minDopt = isolate(input$mindopt),
                            parallel = isolate(as.logical(input$parallel)),
                            advancedoptions = list(GUI = TRUE, progressBarUpdater = inc_progress_session))
-          if (isolate(input$trials) %% isolate(input$numberblocks) == 0) {
-            sizevector = isolate(input$trials) / isolate(input$numberblocks)
-          } else {
-            sizevector = c(rep(ceiling(isolate(input$trials) / isolate(input$numberblocks)), isolate(input$numberblocks)))
-            unbalancedruns = ceiling(isolate(input$trials) / isolate(input$numberblocks)) * isolate(input$numberblocks) - isolate(input$trials)
-            sizevector[(length(sizevector) - unbalancedruns + 1):length(sizevector)] = sizevector[(length(sizevector) - unbalancedruns + 1):length(sizevector)] - 1
-          }
         })
         withProgress(message = "Generating full design:", value = 0, min = 0, max = 1, expr = {
           design = gen_design(candidateset = isolate(expand.grid(candidatesetall())),
                               model = isolate(as.formula(input$model)),
                               trials = isolate(input$trials),
                               splitplotdesign = spd,
-                              blocksizes = sizevector,
                               optimality = isolate(optimality()),
                               repeats = isolate(input$repeats),
                               varianceratio = isolate(input$varianceratio),
@@ -855,7 +835,7 @@ function(input, output, session) {
     }
     display_table = display_table %>%
       data_color(columns = "power",
-                 colors = scales::col_numeric(palette =colorRampPalette(c("white", "darkgreen"))(100),
+                 palette = scales::col_numeric(palette =colorRampPalette(c("white", "darkgreen"))(100),
                                               domain =c(0,1)),
                  alpha = 0.3,
                  autocolor_text = FALSE) %>%
@@ -1007,14 +987,14 @@ function(input, output, session) {
         display_rm = display_rm %>%
           data_color(
             columns = cols_rm[i],
-            colors = pal_option(100),
+            palette = pal_option(100),
             alpha = alpha,
             autocolor_text = FALSE)
       } else {
         display_rm = display_rm %>%
           data_color(
             columns = cols_rm[i],
-            colors = pal_option(length(unique(runmat[,i]))),
+            palette = pal_option(length(unique(runmat[,i]))),
             alpha = alpha,
             autocolor_text = FALSE)
       }
